/*---------------------------------------------------
-----------------------------------------------------
Filename:	songinfo.m
Version:	1.0

Type:		maki
Date:		20. Nov. 2006 - 22:47 
Author:		Martin Poehlmann aka Deimos (+ victhor mods to enlarge - 2017)
E-Mail:		martin@skinconsortium.com
Internet:	www.skinconsortium.com
		www.martin.deimos.de.vu
-----------------------------------------------------
---------------------------------------------------*/

#include "std.mi"

Function int getChannels (); // returning 1 for mono, 2 for stereo, more for multichannel (e.g. 6), -1 for no info available
Function string getBitrate();
Function string getFrequency();

Global layer monster;
Global group scriptGroup, monster_grp;
Global timer delayload, songInfoTimer;

Global Text Bitrate, Frequency, l_Bitrate, l_Bitrate, monostereosurround;

Global int tempwidth;
//Global boolean param; // v1.2 no longer needed

System.onScriptLoaded()
{
	scriptGroup = getScriptgroup();

	monster_grp = scriptGroup.findObject("monster.group");
	monster = monster_grp.findObject("monster");
	monostereosurround = monster_grp.findObject("monostereosurround");
	
	Bitrate = scriptGroup.findObject("Bitrate");
	Frequency = scriptGroup.findObject("Frequency");

	delayload = new Timer;
	delayload.setDelay(100);

	songInfoTimer = new Timer;
	songInfoTimer.setDelay(1000);
}


system.onScriptUnloading ()
{
	songinfotimer.stop();
	delete songinfotimer;
	delayload.stop();
	delete delayload;
}

System.onResume()
{
	delayload.start();
	songInfoTimer.start();
}

System.onPlay()
{
	delayload.start();
	songInfoTimer.start();
}

System.onStop ()
{
	songInfoTimer.stop();
}

system.onPause ()
{
	songInfoTimer.stop();
}

System.onTitleChange(String newtitle)
{
	delayload.start();
	Bitrate.setText(getBitrate()); 
}

delayload.onTimer ()
{
  delayload.stop();
	int c = getChannels();
	if (c == -1) { monster.setXmlParam("image", "player.songinfo.na"); monostereosurround.setXmlParam("text", "N/A"); }
	else if (c == 1) { monster.setXmlParam("image", "player.songinfo.mono"); monostereosurround.setXmlParam("text", "MONO");  }
	else if (c == 2 || c == 3) { monster.setXmlParam("image", "player.songinfo.stereo"); monostereosurround.setXmlParam("text", "STEREO");  }
	else if (c >= 3) { monster.setXmlParam("image", "player.songinfo.multi2"); monostereosurround.setXmlParam("text", "SURROUND");  }	
	else
	{
		if (tempwidth > 33) { monster.setXmlParam("image", "player.songinfo.multi2"); monostereosurround.setXmlParam("text", "SURROUND"); }
		else { monster.setXmlParam("image", "player.songinfo.multi"); monostereosurround.setXmlParam("text", "SURRND"); }
	}
	
	//ensure to display bitrate & frequency
	Bitrate.setText(getBitrate());
	Frequency.setText(getFrequency());
}

Int getChannels ()
{
	if (strsearch(getSongInfoText(), "tereo") != -1)
	{
		return 2;
	}
	else if (strsearch(getSongInfoText(), "ono") != -1)
	{
		return 1;
	}
	else if (strsearch(getSongInfoText(), "annels") != -1)
	{
		int pos = strsearch(getSongInfoText(), "annels");
		return stringToInteger(strmid(getSongInfoText(), pos - 4, 1));
	}
	else
	{
		return -1;
	}
}

songInfoTimer.onTimer ()
{
	Bitrate.setText(getBitrate());
  Frequency.setText(getFrequency());
}

string getBitrate ()
{
	string sit = strlower(getSongInfoText());
	if (sit != "")
	{
		string rtn;
		int searchresult;
		for (int i = 0; i < 5; i++) {
			rtn = getToken(sit, " ", i);
			searchResult = strsearch(rtn, "kbps");
			if (searchResult>0) return StrMid(rtn, 0, searchResult);
		}
		return "";
	}
	else
	{
		return "";
	}
}

string getFrequency ()
{
	string sit = strlower(getSongInfoText());
	if (sit != "")
	{
		string rtn;
		int searchresult;
		for (int i = 0; i < 5; i++) {
			rtn = getToken(sit, " ", i);
			searchResult = strsearch(strlower(rtn), "khz");
			if (searchResult>0) 
			{
				rtn = StrMid(rtn, 0, searchResult);
				searchResult = strsearch(strlower(rtn), ".");
				if (searchResult>0)
				{
					rtn = getToken(rtn, ".", 0);
				}
				return rtn;
			}
		}
		return "";
	}
	else
	{
		return "";
	}
}

/*Bitrate.onTextChanged (String newtxt)
{
	if (param) return;
	if (Bitrate.getTextWidth() == tempwidth) return;
	tempwidth = getTextWidth();
	if (getTextWidth() >  26)
	{
		Bitrate.setXmlParam("w", "32"); // or Bitrate.setXmlParam("image", "imagewithwidthof32");
		BitrateLabel.setXmlParam("x", "60");
		Frequency.setXmlParam("x", "104");
		FrequencyLabel.setXmlParam("x", "136");
	}
	else
	{
		Bitrate.setXmlParam("w", "26");
		BitrateLabel.setXmlParam("x", "40");
		Frequency.setXmlParam("x", "96");
		FrequencyLabel.setXmlParam("x", "128");
	}
}*/

scriptGroup.onSetVisible(Boolean onoff) // v1.2 added to update when showing in a paused state
{
	delayload.start();
	songInfoTimer.start();
}